function [Phi,P] = double_test_h(M,runs)
%function [Phi,P] = double_test_h(M,runs)
%Finds P-value for difference in h between 2 pops
%Phi is the higher P-value.
%P stores P-value for Bootstrap and Z-test respectively
%For conservative test, use Phi only
%see also Thomas et al. 2002, AJHG 70: 1411-1420
%M has two columns only, one for each pop.
%runs = No. of bootstrap sims to perform

P=zeros(2,1);

%Method 2 (bootstrap)
simh = boot_h(M,runs);
diff = simh(:,1) - simh(:,2);
P(1) = 2*min([sum(diff<=0) sum(diff>=0)])/runs;

%Method 3 (Z-test)
[h,varh] = Nei_h(M);
se_diff = sqrt(sum(varh));
Z = abs(h(1)-h(2))/se_diff;
P(2) = erfc(Z/sqrt(2));

Phi = max(P);
